@@ -250,7 +250,7 @@ class DataFrame:
 
     def __to_np_arrays__(self,has_header = True):
         shape = self.shape()
-        columns = np.empty(shape[0],list)
+        columns = np.empty(shape[1],list)
         lines = self.values(clear = False).split("\n")
         str_types = self.get_types().values()
         types = []
@@ -284,6 +284,9 @@ class DataFrame:
 
     def to_npd(self):
         names,columns,types = self.__to_np_arrays__()
+#         print(names)
+#         print(columns)
+#         print(types)
         t = npd.DataFrame()
         for i in range(len(names)):
             t[names[i]] = np.array(columns[i]).astype(types[i])
@@ -291,6 +294,9 @@ class DataFrame:
 
     def to_pandas(self):
         names,columns,types = self.__to_np_arrays__()
+#         print(names)
+#         print(columns)
+#         print(types)
         df = pd.DataFrame()
         for i in range(len(names)):
             df[names[i]] = np.array(columns[i]).astype(types[i])
@@ -985,7 +991,7 @@ class DataFrame:
         self.clear_commands()
         return __ddf__
 
-    def to_csv(self,path_output,append=False,clear_all_commands = True,set_as_new_path = True):
+    def to_csv(self,path_output,append=False,clear_all_commands = False,set_as_new_path = False):
         if not append:
             command = "xargs -I {} echo {}>" + path_output
             awk_command = Awk_command()
